======
emoji2
======


.. image:: https://img.shields.io/pypi/v/emoji2.svg
        :target: https://pypi.python.org/pypi/emoji2

.. image:: https://img.shields.io/travis/lonsty/emoji.svg
        :target: https://travis-ci.org/lonsty/emoji

.. image:: https://readthedocs.org/projects/emoji2/badge/?version=latest
        :target: https://emoji2.readthedocs.io/en/latest/?badge=latest
        :alt: Documentation Status




Search emoji by keywords in terminal.


* Free software: MIT license
* Documentation: https://emoji2.readthedocs.io.


Features
--------

* Search emoji by keywords in terminal.
* Easily add emoji anywhere.

Credits
-------

This package was created with Cookiecutter_ and the `audreyr/cookiecutter-pypackage`_ project template.

.. _Cookiecutter: https://github.com/audreyr/cookiecutter
.. _`audreyr/cookiecutter-pypackage`: https://github.com/audreyr/cookiecutter-pypackage
